@@ -1,6 +1,6 @@
 package Statocles::Base;
 # ABSTRACT: Base module for Statocles modules
-$Statocles::Base::VERSION = '0.049';
+$Statocles::Base::VERSION = '0.050';
 use strict;
 use warnings;
 use base 'Import::Base';
@@ -28,7 +28,7 @@ my @class_modules = (
 
 our %IMPORT_BUNDLES = (
     Test => [
-        qw( Test::More Test::Deep Test::Differences Test::Exception Test::Lib ),
+        qw( Test::More Test::Deep Test::Differences Test::Exception ),
         'Dir::Self' => [qw( __DIR__ )],
         'Path::Tiny' => [qw( path tempdir cwd )],
         'Statocles::Test' => [qw(
@@ -71,7 +71,7 @@ Statocles::Base - Base module for Statocles modules
 
 =head1 VERSION
 
-version 0.049
+version 0.050
 
 =head1 SYNOPSIS
 
