@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.049';
+$Statocles::Site::VERSION = '0.050';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -250,7 +250,7 @@ sub build {
             for my $attr ( qw( src href ) ) {
                 for my $el ( $dom->find( "[$attr]" )->each ) {
                     my $url = $el->attr( $attr );
-                    next unless $url =~ m{^/[^/]};
+                    next unless $url =~ m{^/(?:[^/]|$)};
 
                     # Rewrite links to the index app's index page
                     if ( $index_root && $url =~ m{^$index_root(?:/index[.]html)?$} ) {
@@ -345,7 +345,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.049
+version 0.050
 
 =head1 SYNOPSIS
 
